@@ -1,5 +1,5 @@
 /* OGMDvd - A wrapper library around libdvdread
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -437,7 +437,7 @@ ogmdvd_title_get_display_format (OGMDvdTitle *title)
  *
  * Returns: a constant array of 16 integers, or NULL
  */
-G_CONST_RETURN guint *
+const guint *
 ogmdvd_title_get_palette (OGMDvdTitle *title)
 {
   g_return_val_if_fail (title != NULL, NULL);
@@ -493,12 +493,6 @@ ogmdvd_title_get_n_audio_streams (OGMDvdTitle *title)
   return title->nr_of_audio_streams;
 }
 
-static gint
-ogmdvd_stream_find_by_nr (OGMDvdStream *stream, guint nr)
-{
-  return stream->nr - nr;
-}
-
 /**
  * ogmdvd_title_get_nth_audio_stream:
  * @title: An #OGMDvdTitle
@@ -511,20 +505,23 @@ ogmdvd_stream_find_by_nr (OGMDvdStream *stream, guint nr)
 OGMDvdAudioStream *
 ogmdvd_title_get_nth_audio_stream (OGMDvdTitle *title, guint nr)
 {
-  OGMDvdAudioStream *audio = NULL;
   GSList *link;
 
   g_return_val_if_fail (title != NULL, NULL);
   g_return_val_if_fail (nr < title->nr_of_audio_streams, NULL);
 
-  link = g_slist_find_custom (title->audio_streams, GUINT_TO_POINTER (nr), (GCompareFunc) ogmdvd_stream_find_by_nr);
-  if (link)
+  for (link = title->audio_streams; link; link = link->next)
   {
-    audio = link->data;
-    ogmdvd_stream_ref (&audio->stream);
+    OGMDvdAudioStream *audio = link->data;
+
+    if (audio->stream.nr == nr)
+    {
+      ogmdvd_stream_ref (&audio->stream);
+      return audio;
+    }
   }
 
-  return audio;
+  return NULL;
 }
 
 /**
@@ -602,20 +599,23 @@ ogmdvd_title_get_n_subp_streams (OGMDvdTitle *title)
 OGMDvdSubpStream *
 ogmdvd_title_get_nth_subp_stream (OGMDvdTitle *title, guint nr)
 {
-  OGMDvdSubpStream *subp = NULL;
   GSList *link;
 
   g_return_val_if_fail (title != NULL, NULL);
   g_return_val_if_fail (nr < title->nr_of_subp_streams, NULL);
 
-  link = g_slist_find_custom (title->subp_streams, GUINT_TO_POINTER (nr), (GCompareFunc) ogmdvd_stream_find_by_nr);
-  if (link)
+  for (link = title->subp_streams; link; link = link->next)
   {
-    subp = link->data;
-    ogmdvd_stream_ref (&subp->stream);
+    OGMDvdSubpStream *subp = link->data;
+
+    if (subp->stream.nr == nr)
+    {
+      ogmdvd_stream_ref (&subp->stream);
+      return subp;
+    }
   }
 
-  return subp;
+  return NULL;
 }
 
 /**
