@@ -1,5 +1,5 @@
 /* OGMJob - A library to spawn processes
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -108,12 +108,8 @@ ogmjob_pipeline_child_progress (OGMJobPipeline *pipeline, gdouble fraction, OGMJ
 static void
 ogmjob_pipeline_add (OGMJobContainer *container, OGMJobSpawn *child)
 {
-  guint handler;
-
-  handler = g_signal_connect_swapped (child, "progress", 
+  g_signal_connect_swapped (child, "progress", 
       G_CALLBACK (ogmjob_pipeline_child_progress), container);
-  g_object_set_data (G_OBJECT (child), "__child_progress_handler__", 
-      GUINT_TO_POINTER (handler));
 
   OGMJOB_CONTAINER_CLASS (ogmjob_pipeline_parent_class)->add (container, child);
 }
@@ -121,11 +117,8 @@ ogmjob_pipeline_add (OGMJobContainer *container, OGMJobSpawn *child)
 static void
 ogmjob_pipeline_remove (OGMJobContainer *container, OGMJobSpawn *child)
 {
-  gpointer handler;
-
-  handler = g_object_get_data (G_OBJECT (child), "__child_progress_handler__");
-  if (handler)
-    g_signal_handler_disconnect (child, GPOINTER_TO_UINT (handler));
+  g_signal_handlers_disconnect_by_func (child,
+      ogmjob_pipeline_child_progress, container);
 
   OGMJOB_CONTAINER_CLASS (ogmjob_pipeline_parent_class)->remove (container, child);
 }
