@@ -72,10 +72,9 @@ static int signals[LAST_SIGNAL] = { 0 };
 static void
 ogmrip_chooser_list_chooser_changed (GtkWidget *chooser, OGMRipChooserListItem *item)
 {
-  OGMRipSource *source;
   OGMRipSourceType type;
 
-  source = ogmrip_source_chooser_get_active (OGMRIP_SOURCE_CHOOSER (chooser), &type);
+  ogmrip_source_chooser_get_active (OGMRIP_SOURCE_CHOOSER (chooser), &type);
   gtk_widget_set_sensitive (item->more_button, type == OGMRIP_SOURCE_STREAM);
 }
 
@@ -233,10 +232,11 @@ ogmrip_chooser_list_more_clicked (OGMRipChooserList *list, GtkWidget *button)
 static void
 ogmrip_chooser_list_dispose (GObject *gobject)
 {
+/*
   OGMRipChooserList *list;
   
   list = OGMRIP_CHOOSER_LIST (gobject);
-/*
+
   if (list->priv->client)
     g_object_unref (list->priv->client);
   list->priv->client = NULL;
@@ -472,7 +472,6 @@ ogmrip_chooser_list_foreach (OGMRipChooserList *list, OGMRipSourceType type, GFu
   GList *children, *link;
   gint source_type;
 
-  OGMRipSource *source;
   OGMRipChooserListItem *item;
 
   g_return_if_fail (OGMRIP_IS_CHOOSER_LIST (list));
@@ -482,7 +481,7 @@ ogmrip_chooser_list_foreach (OGMRipChooserList *list, OGMRipSourceType type, GFu
   {
     item = g_object_get_data (G_OBJECT (link->data), "__ogmrip_chooser_list_item__");
 
-    source = ogmrip_source_chooser_get_active (OGMRIP_SOURCE_CHOOSER (item->chooser), &source_type);
+    ogmrip_source_chooser_get_active (OGMRIP_SOURCE_CHOOSER (item->chooser), &source_type);
 
     if (type == OGMRIP_SOURCE_STREAM)
     {
