@@ -1,5 +1,5 @@
-/* OGMRip - A DVD Encoder for GNOME
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+/* OGMRip - A library for DVD ripping and encoding
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -960,13 +960,14 @@ ogmrip_combo_box_get_active_container (GtkComboBox *combo)
 GType
 ogmrip_combo_box_get_active_video_codec (GtkComboBox *combo)
 {
-  GType codec;
+  GType codec = G_TYPE_NONE;
   gchar *name;
 
   g_return_val_if_fail (GTK_IS_COMBO_BOX (combo), G_TYPE_NONE);
 
   name = ogmrip_combo_box_get_active_item (combo);
-  codec = ogmrip_plugin_get_video_codec_by_name (name);
+  if (name)
+    codec = ogmrip_plugin_get_video_codec_by_name (name);
   g_free (name);
 
   return codec;
@@ -983,13 +984,14 @@ ogmrip_combo_box_get_active_video_codec (GtkComboBox *combo)
 GType
 ogmrip_combo_box_get_active_audio_codec (GtkComboBox *combo)
 {
-  GType codec;
+  GType codec = G_TYPE_NONE;
   gchar *name;
 
   g_return_val_if_fail (GTK_IS_COMBO_BOX (combo), G_TYPE_NONE);
 
   name = ogmrip_combo_box_get_active_item (combo);
-  codec = ogmrip_plugin_get_audio_codec_by_name (name);
+  if (name)
+    codec = ogmrip_plugin_get_audio_codec_by_name (name);
   g_free (name);
 
   return codec;
@@ -1006,13 +1008,14 @@ ogmrip_combo_box_get_active_audio_codec (GtkComboBox *combo)
 GType
 ogmrip_combo_box_get_active_subp_codec (GtkComboBox *combo)
 {
-  GType codec;
+  GType codec = G_TYPE_NONE;
   gchar *name;
 
   g_return_val_if_fail (GTK_IS_COMBO_BOX (combo), G_TYPE_NONE);
 
   name = ogmrip_combo_box_get_active_item (combo);
-  codec = ogmrip_plugin_get_subp_codec_by_name (name);
+  if (name)
+    codec = ogmrip_plugin_get_subp_codec_by_name (name);
   g_free (name);
 
   return codec;
