@@ -58,8 +58,8 @@ gchar **
 ogmrip_audio_copy_command (OGMRipAudioCodec *audio, const gchar *input, const gchar *output)
 {
   OGMDvdTitle *title;
+  OGMDvdAudioStream *stream;
   GPtrArray *argv;
-  gint vid;
 
   g_return_val_if_fail (OGMRIP_IS_AUDIO_CODEC (audio), NULL);
 
@@ -70,32 +70,48 @@ ogmrip_audio_copy_command (OGMRipAudioCodec *audio, const gchar *input, const gc
   title = ogmrip_codec_get_input (OGMRIP_CODEC (audio));
   g_return_val_if_fail (title != NULL, NULL);
 
-  argv = ogmrip_mencoder_audio_command (audio, output);
-
-  g_ptr_array_add (argv, g_strdup ("-ovc"));
-  if (MPLAYER_CHECK_VERSION (1,0,0,8))
+  stream = ogmrip_audio_codec_get_dvd_audio_stream (audio);
+  if (ogmdvd_audio_stream_get_format (stream) == OGMDVD_AUDIO_FORMAT_LPCM)
   {
+    ogmrip_audio_codec_set_fast (audio, FALSE);
+    ogmrip_audio_codec_set_normalize (audio, FALSE);
+    ogmrip_audio_codec_set_sample_rate (audio, 48000);
+    ogmrip_audio_codec_set_channels (audio,
+        ogmdvd_audio_stream_get_channels (stream));
+
+    argv = ogmrip_mplayer_wav_command (audio, FALSE, output);
+  }
+  else
+  {
+    gint vid;
+
+    argv = ogmrip_mencoder_audio_command (audio, output);
+
+    g_ptr_array_add (argv, g_strdup ("-ovc"));
+    if (MPLAYER_CHECK_VERSION (1,0,0,8))
+    {
+      g_ptr_array_add (argv, g_strdup ("copy"));
+      g_ptr_array_add (argv, g_strdup ("-of"));
+      g_ptr_array_add (argv, g_strdup ("rawaudio"));
+    }
+    else
+      g_ptr_array_add (argv, g_strdup ("frameno"));
+
+    g_ptr_array_add (argv, g_strdup ("-oac"));
     g_ptr_array_add (argv, g_strdup ("copy"));
-    g_ptr_array_add (argv, g_strdup ("-of"));
-    g_ptr_array_add (argv, g_strdup ("rawaudio"));
-  }
-  else
-    g_ptr_array_add (argv, g_strdup ("frameno"));
 
-  g_ptr_array_add (argv, g_strdup ("-oac"));
-  g_ptr_array_add (argv, g_strdup ("copy"));
+    vid = ogmdvd_title_get_nr (title);
 
-  vid = ogmdvd_title_get_nr (title);
-
-  if (MPLAYER_CHECK_VERSION (1,0,0,1))
-    g_ptr_array_add (argv, g_strdup_printf ("dvd://%d", vid + 1));
-  else
-  {
-    g_ptr_array_add (argv, g_strdup ("-dvd"));
-    g_ptr_array_add (argv, g_strdup_printf ("%d", vid + 1));
+    if (MPLAYER_CHECK_VERSION (1,0,0,1))
+      g_ptr_array_add (argv, g_strdup_printf ("dvd://%d", vid + 1));
+    else
+    {
+      g_ptr_array_add (argv, g_strdup ("-dvd"));
+      g_ptr_array_add (argv, g_strdup_printf ("%d", vid + 1));
+    }
   }
 
-  g_ptr_array_add (argv, NULL);
+    g_ptr_array_add (argv, NULL);
 
   return (gchar **) g_ptr_array_free (argv, FALSE);
 }
