@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -48,8 +48,7 @@ struct _OGMRipChaptersClass
 GType         ogmrip_chapters_get_type  (void);
 OGMJobSpawn * ogmrip_chapters_new       (OGMDvdTitle    *title,
                                          const gchar    *output);
-G_CONST_RETURN 
-gchar *       ogmrip_chapters_get_label (OGMRipChapters *chapters, 
+const gchar * ogmrip_chapters_get_label (OGMRipChapters *chapters, 
                                          guint          n);
 void          ogmrip_chapters_set_label (OGMRipChapters *chapters, 
                                          guint          n, 
