@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -53,8 +53,7 @@ struct _OGMRipCodecClass
 };
 
 GType         ogmrip_codec_get_type            (void);
-G_CONST_RETURN
-gchar *       ogmrip_codec_get_output          (OGMRipCodec *codec);
+const gchar * ogmrip_codec_get_output          (OGMRipCodec *codec);
 void          ogmrip_codec_set_output          (OGMRipCodec *codec,
                                                 const gchar *output);
 OGMDvdTitle * ogmrip_codec_get_input           (OGMRipCodec *codec);
