@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -51,7 +51,7 @@ static gchar *ogmrip_tmp_dir = NULL;
  * 
  * Returns: The temporaty directory
  */
-G_CONST_RETURN gchar *
+const gchar *
 ogmrip_fs_get_tmp_dir (void)
 {
   if (!ogmrip_tmp_dir)
@@ -618,7 +618,7 @@ ogmrip_fs_rename (const gchar *old_name, const gchar *new_name, GError **error)
  * 
  * Returns: The extension, or NULL
  */
-G_CONST_RETURN gchar *
+const gchar *
 ogmrip_fs_get_extension (const gchar *filename)
 {
   gchar *dot;
