@@ -96,11 +96,8 @@ static void
 ogmrip_mov_class_init (OGMRipMovClass *klass)
 {
   OGMJobSpawnClass *spawn_class;
-  OGMRipContainerClass *container_class;
 
   spawn_class = OGMJOB_SPAWN_CLASS (klass);
-  container_class = OGMRIP_CONTAINER_CLASS (klass);
-
   spawn_class->run = ogmrip_mov_run;
 }
 
