@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -103,15 +103,25 @@ typedef struct
 
 typedef struct
 {
-  gboolean content;
-  gboolean progressive;
-  gboolean telecine;
-  gint affinity;
-  gint duration;
+  gchar *cur_affinity;
+  gchar* prev_affinity;
+  guint naffinities;
+  guint cur_duration;
+  guint prev_duration;
+  guint npatterns;
+  guint cur_section;
+  guint nsections;
   guint nframes;
   guint frames;
 } OGMRipAnalyze;
 
+enum
+{
+  SECTION_UNKNOWN,
+  SECTION_24000_1001,
+  SECTION_30000_1001
+};
+
 enum 
 {
   PROP_0,
@@ -146,12 +156,6 @@ static void ogmrip_video_codec_cancel       (OGMJobSpawn  *spawn);
 
 static const gchar *deinterlacer[] = { "lb", "li", "ci", "md", "fd", "l5", "kerndeint", "yadif=0" };
 
-static gint
-g_ulist_compare (UInfo *info, gint val)
-{
-  return info->val - val;
-}
-
 static gint
 g_ulist_min (UInfo *info1, UInfo *info2)
 {
@@ -170,7 +174,14 @@ g_ulist_add (GSList *ulist, GCompareFunc func, gint val)
   GSList *ulink;
   UInfo *info;
 
-  ulink = g_slist_find_custom (ulist, GINT_TO_POINTER (val), (GCompareFunc) g_ulist_compare);
+  for (ulink = ulist; ulink; ulink = ulink->next)
+  {
+    info = ulink->data;
+
+    if (info->val == val)
+      break;
+  }
+
   if (ulink)
   {
     info = ulink->data;
@@ -280,36 +291,38 @@ ogmrip_video_codec_analyze_watch (OGMJobExec *exec, const gchar *buffer, OGMRipA
   }
   else
   {
-    if (!info->progressive)
-      info->progressive = g_str_has_prefix (buffer, "demux_mpg:") && strstr (buffer, "24000/1001");
-
-    if (!info->content)
+    if (g_str_has_prefix (buffer, "demux_mpg: 24000/1001"))
     {
-      gint duration;
-
-      if (sscanf (buffer, "duration: %d", &duration) == 1)
-      {
-        info->content = info->duration == 3 && duration == 2;
-        info->duration = duration;
-      }
+      info->cur_section = SECTION_24000_1001;
+      info->nsections ++;
     }
-    else
+    else if (g_str_has_prefix (buffer, "demux_mpg: 30000/1001"))
     {
-      if (!info->telecine)
+      info->cur_section = SECTION_30000_1001;
+      info->nsections ++;
+    }
+
+    if (info->cur_section == SECTION_30000_1001)
+    {
+      if (g_str_has_prefix (buffer, "affinity: "))
       {
-        if (g_str_has_prefix (buffer, "affinity: "))
+        g_free (info->prev_affinity);
+        info->prev_affinity = g_strdup (info->cur_affinity);
+
+        g_free (info->cur_affinity);
+        info->cur_affinity = g_strdup (buffer + 10);
+      }
+      else if (g_str_has_prefix (buffer, "duration: "))
+      {
+        info->prev_duration = info->cur_duration;
+        sscanf (buffer, "duration: %u", &info->cur_duration);
+
+        if (info->prev_duration == 3 && info->cur_duration == 2)
         {
-          gint affinity;
+          info->npatterns ++;
 
-          if (g_str_has_prefix (buffer + 10, ".0+.1.+2"))
-            affinity = 1;
-          else if (g_str_has_prefix (buffer + 10, ".0++1"))
-            affinity = 2;
-          else
-            affinity = 0;
-
-          info->telecine = info->affinity == 1 && affinity == 2;
-          info->affinity = affinity;
+          if (strncmp (info->prev_affinity, ".0+.1.+2", 8) == 0 && strncmp (info->cur_affinity, ".0++1", 5) == 0)
+            info->naffinities ++;
         }
       }
     }
@@ -1977,12 +1990,47 @@ ogmrip_video_codec_analyze (OGMRipVideoCodec *video, guint nframes)
   if (video->priv->child_canceled)
     return FALSE;
 
-  video->priv->interlaced = analyze.content && !analyze.telecine ? 1 : 0;
+  if (analyze.nsections > 0)
+  {
+    /*
+     * Progressive
+     */
+    if (analyze.cur_section == SECTION_24000_1001 && analyze.nsections == 1)
+    {
+      ogmrip_codec_set_progressive (OGMRIP_CODEC (video), TRUE);
+      ogmrip_codec_set_telecine (OGMRIP_CODEC (video), FALSE);
+      ogmrip_video_codec_set_deinterlacer (video, OGMRIP_DEINT_NONE);
+    }
+    else if (analyze.nsections > 1)
+    {
+      ogmrip_codec_set_progressive (OGMRIP_CODEC (video), TRUE);
+      if (analyze.npatterns > 0 && analyze.naffinities > 0)
+      {
+        /*
+         * Mixed progressive and telecine
+         */
+        ogmrip_codec_set_telecine (OGMRIP_CODEC (video), TRUE);
+        ogmrip_video_codec_set_deinterlacer (video, OGMRIP_DEINT_NONE);
+      }
+      else
+      {
+        /*
+         * Mixed progressive and interlaced
+         */
+        ogmrip_codec_set_telecine (OGMRIP_CODEC (video), FALSE);
+        ogmrip_video_codec_set_deinterlacer (video, OGMRIP_DEINT_YADIF);
+      }
+    }
+  }
+  else
+  {
+    ogmrip_codec_set_telecine (OGMRIP_CODEC (video), FALSE);
+    ogmrip_codec_set_progressive (OGMRIP_CODEC (video), FALSE);
+    ogmrip_video_codec_set_deinterlacer (video, OGMRIP_DEINT_NONE);
+  }
 
-  ogmrip_video_codec_set_deinterlacer (video,
-      video->priv->interlaced ? OGMRIP_DEINT_YADIF: OGMRIP_DEINT_NONE);
-  ogmrip_codec_set_telecine (OGMRIP_CODEC (video), analyze.content && analyze.telecine);
-  ogmrip_codec_set_progressive (OGMRIP_CODEC (video), analyze.progressive);
+  g_free (analyze.prev_affinity);
+  g_free (analyze.cur_affinity);
 
   return TRUE;
 }
