@@ -1259,7 +1259,7 @@ ogmrip_options_dialog_set_crop (OGMRipOptionsDialog *dialog, OGMRipOptionsType t
     right = dialog->priv->raw_width - x - width;
 
   if (dialog->priv->raw_height > y + height)
-    bottom = dialog->priv->raw_height - x - height;
+    bottom = dialog->priv->raw_height - y - height;
 
   ogmrip_options_dialog_set_crop_internal (dialog, type, x, y, right, bottom);
 }
