@@ -1,5 +1,5 @@
 /* OGMRip - A DVD Encoder for GNOME
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -625,27 +625,27 @@ ogmrip_profile_editor_dialog_container_combo_changed (OGMRipProfileEditorDialog
 static void
 ogmrip_profile_editor_dialog_video_codec_combo_changed (OGMRipProfileEditorDialog *dialog, GtkWidget *combo)
 {
-  GtkTreeIter iter;
+  GType codec;
 
-  if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combo), &iter))
+  codec = ogmrip_combo_box_get_active_video_codec (GTK_COMBO_BOX (combo));
+  if (codec != G_TYPE_NONE)
   {
-    GType codec;
     GtkTreeModel *model;
+    GtkTreeIter iter;
     gboolean exists;
     gint active;
-    gchar *name;
 
-    model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
-    gtk_tree_model_get (model, &iter, 1, &name, -1);
+    model = gtk_combo_box_get_model (GTK_COMBO_BOX (dialog->priv->video_preset_combo));
 
-    codec = ogmrip_profile_editor_dialog_get_video_codec_type (dialog, name);
-    g_free (name);
-
-    gtk_combo_box_remove_text (GTK_COMBO_BOX (dialog->priv->video_preset_combo), OGMRIP_VIDEO_PRESET_USER);
+    if (gtk_tree_model_iter_nth_child (model, &iter, NULL, OGMRIP_VIDEO_PRESET_USER))
+      gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
 
     exists = ogmrip_options_plugin_exists (codec);
     if (exists)
-      gtk_combo_box_append_text (GTK_COMBO_BOX (dialog->priv->video_preset_combo), _("User"));
+    {
+      gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+      gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, _("User"), -1);
+    }
 
     active = gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->priv->video_preset_combo));
     
@@ -660,21 +660,12 @@ ogmrip_profile_editor_dialog_video_codec_combo_changed (OGMRipProfileEditorDialo
 static void
 ogmrip_profile_editor_dialog_audio_codec_combo_changed (OGMRipProfileEditorDialog *dialog, GtkWidget *combo)
 {
-  GtkTreeIter iter;
-
-  if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combo), &iter))
+  if (dialog->priv->audio_options_button)
   {
     GType codec;
-    GtkTreeModel *model;
-    gchar *name;
 
-    model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
-    gtk_tree_model_get (model, &iter, 1, &name, -1);
-
-    codec = ogmrip_profile_editor_dialog_get_audio_codec_type (dialog, name);
-    g_free (name);
-
-    if (dialog->priv->audio_options_button)
+    codec = ogmrip_combo_box_get_active_audio_codec (GTK_COMBO_BOX (combo));
+    if (codec != G_TYPE_NONE)
       gtk_widget_set_sensitive (dialog->priv->audio_options_button,
           ogmrip_options_plugin_exists (codec));
   }
@@ -683,21 +674,12 @@ ogmrip_profile_editor_dialog_audio_codec_combo_changed (OGMRipProfileEditorDialo
 static void
 ogmrip_profile_editor_dialog_subp_codec_combo_changed (OGMRipProfileEditorDialog *dialog, GtkWidget *combo)
 {
-  GtkTreeIter iter;
-
-  if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combo), &iter))
+  if (dialog->priv->subp_options_button)
   {
     GType codec;
-    GtkTreeModel *model;
-    gchar *name;
 
-    model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
-    gtk_tree_model_get (model, &iter, 1, &name, -1);
-
-    codec = ogmrip_profile_editor_dialog_get_subp_codec_type (dialog, name);
-    g_free (name);
-
-    if (dialog->priv->subp_options_button)
+    codec = ogmrip_combo_box_get_active_subp_codec (GTK_COMBO_BOX (combo));
+    if (codec != G_TYPE_NONE)
       gtk_widget_set_sensitive (dialog->priv->subp_options_button,
           ogmrip_options_plugin_exists (codec));
   }
@@ -754,7 +736,9 @@ ogmrip_profile_editor_dialog_init (OGMRipProfileEditorDialog *dialog)
       GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
       NULL);
   gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+#if !GTK_CHECK_VERSION(2,22,0)
   gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+#endif
   gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
   gtk_window_set_icon_from_stock (GTK_WINDOW (dialog), GTK_STOCK_PREFERENCES);
@@ -951,7 +935,7 @@ ogmrip_profile_editor_dialog_init (OGMRipProfileEditorDialog *dialog)
   dialog->priv->audio_quality_label = glade_xml_get_widget (xml, "audio-quality-label");
   dialog->priv->audio_quality_spin = glade_xml_get_widget (xml, "audio-quality-spin");
   ogmrip_settings_bind (settings, dialog->priv->profile_section,
-      OGMRIP_GCONF_AUDIO_QUALITY, G_OBJECT (widget), "value");
+      OGMRIP_GCONF_AUDIO_QUALITY, G_OBJECT (dialog->priv->audio_quality_spin), "value");
 
   widget = glade_xml_get_widget (xml, "normalize-check");
   ogmrip_settings_bind (settings, dialog->priv->profile_section,
