@@ -1,5 +1,5 @@
 /* OGMRip - A DVD Encoder for GNOME
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -404,7 +404,9 @@ ogmrip_progress_dialog_init (OGMRipProgressDialog *dialog)
   gtk_window_set_default_size (GTK_WINDOW (dialog), 450, -1);
   gtk_window_set_icon_from_stock (GTK_WINDOW (dialog), GTK_STOCK_EXECUTE);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
+#if !GTK_CHECK_VERSION(2,22,0)
   gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+#endif
 
   area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 
@@ -418,8 +420,7 @@ ogmrip_progress_dialog_init (OGMRipProgressDialog *dialog)
   g_signal_connect_swapped (dialog->priv->status_icon, "popup_menu",
       G_CALLBACK (ogmrip_progress_dialog_status_icon_popup_menu), dialog);
 
-  dialog->priv->notification = notify_notification_new_with_status_icon ("Dummy", "Dummy",
-      OGMRIP_DATA_DIR G_DIR_SEPARATOR_S OGMRIP_ICON_FILE, dialog->priv->status_icon);
+  dialog->priv->notification = notify_notification_new ("Dummy", "Dummy", NULL);
   g_signal_connect (dialog, "window-state-event",
       G_CALLBACK (ogmrip_progress_dialog_state_changed), NULL);
 
